[llvm-commits] CVS: llvm/include/llvm/Target/TargetInstrInfo.h

Alkis Evlogimenos alkis at cs.uiuc.edu
Sat Jul 31 02:38:02 PDT 2004



Changes in directory llvm/include/llvm/Target:

TargetInstrInfo.h updated: 1.64 -> 1.65

---
Log message:

Change signature to take two basic blocks: the target and the one
where the goto will be appended.


---
Diffs of the changes:  (+4 -4)

Index: llvm/include/llvm/Target/TargetInstrInfo.h
diff -u llvm/include/llvm/Target/TargetInstrInfo.h:1.64 llvm/include/llvm/Target/TargetInstrInfo.h:1.65
--- llvm/include/llvm/Target/TargetInstrInfo.h:1.64	Sat Jul 31 03:57:27 2004
+++ llvm/include/llvm/Target/TargetInstrInfo.h	Sat Jul 31 04:37:52 2004
@@ -155,10 +155,10 @@
     return false;
   }
 
-  /// Insert a goto (unconditional branch) sequence to MBB, right
-  /// before MBBI
-  virtual void insertGoto(const MachineBasicBlock& MBB,
-                          MachineBasicBlock::iterator MBBI) const {
+  /// Insert a goto (unconditional branch) sequence to TMBB, at the
+  /// end of MBB
+  virtual void insertGoto(MachineBasicBlock& MBB,
+                          MachineBasicBlock& TMBB) const {
     assert(0 && "Target didn't implement insertGoto!");
   }
 





More information about the llvm-commits mailing list